@@ -1,4 +1,6 @@
 """*SDK configuration and options*."""
+from typing import Optional
+
 from iscc_core.options import CoreOptions
 from pydantic import Field
 
@@ -30,5 +32,10 @@ class SdkOptions(CoreOptions):
         60, description="Thumbnail image compression setting (0-100)"
     )
 
+    video_fps: int = Field(
+        5,
+        description="Frames per second to process for video hash (ignored when 0).",
+    )
+
 
 sdk_opts = SdkOptions()
